==> scala-relay-compiler-0.8.1.tgz: package/realex/multipleroots/out/SpecificUserView_fullUser.scala <==
/**
 * scala-relay-compiler: 
 * GENERATED, DON'T MANUALLY EDIT.
 */
package relay.generated
/*

objName:      fragment
docType:      ConcreteFragment
*/

import _root_.scala.scalajs.js
import _root_.scala.scalajs.js.|

trait SpecificUserView_fullUser extends js.Object {
  /** No spreads, just combining. */
  val policies : SpecificUserView_fullUser.Policies
  val id : String
  val rawId : String
}


object SpecificUserView_fullUser extends _root_.relay.graphql.GenericGraphQLTaggedNode {

  ////////////////////////////////////
  ////// Supporting classes begin here
  ////////////////////////////////////
  trait PoliciesEdgesNode extends js.Object {
    val quoteId : String
  }
  trait PoliciesEdges extends js.Object with _root_.relay.runtime.Edge[PoliciesEdgesNode] {
    /** No spreads, just combining. */
    val node : PoliciesEdgesNode
  }
  trait Policies extends js.Object with _root_.relay.runtime.Connection[PoliciesEdges] {
    /** No spreads, just combining. */
    val edges : js.Array[PoliciesEdges]
  }

  ///////////////////////////
  ////// Implicits begin here
  ///////////////////////////



  val query: _root_.relay.graphql.ConcreteFragment = _root_.scala.scalajs.js.JSON.parse("""{
  "argumentDefinitions": [],
  "kind": "Fragment",
  "metadata": null,
  "name": "SpecificUserView_fullUser",
  "selections": [
    {
      "kind": "ScalarField",
      "alias": null,
      "args": null,
      "name": "rawId",
      "storageKey": null
    },
    {
      "kind": "ScalarField",
      "alias": null,
      "args": null,
      "name": "id",
      "storageKey": null
    },
    {
      "kind": "LinkedField",
      "alias": null,
      "args": null,
      "concreteType": "PolicyMaterializedConnection",
      "name": "policies",
      "plural": false,
      "selections": [
        {
          "kind": "LinkedField",
          "alias": null,
          "args": null,
          "concreteType": "PolicyMaterializedEdge",
          "name": "edges",
          "plural": true,
          "selections": [
            {
              "kind": "LinkedField",
              "alias": null,
              "args": null,
              "concreteType": "PolicyMaterialized",
              "name": "node",
              "plural": false,
              "selections": [
                {
                  "kind": "ScalarField",
                  "alias": null,
                  "args": null,
                  "name": "quoteId",
                  "storageKey": null
                }
              ],
              "storageKey": null
            }
          ],
          "storageKey": null
        }
      ],
      "storageKey": null
    }
  ],
  "type": "FullUser"
}""").asInstanceOf[_root_.relay.graphql.ConcreteFragment]
  val devText: String = """"""
}

==> scala-relay-compiler-0.12.0.tgz: package/realex/multipleroots/out/SpecificUserView_fullUser.scala <==
/**
 * scala-relay-compiler: 
 * GENERATED, DON'T MANUALLY EDIT.
 * objName:      fragment
 * docType:      ConcreteFragment
 */
package relay.generated

import _root_.scala.scalajs.js
import _root_.scala.scalajs.js.|

trait SpecificUserView_fullUser extends js.Object {
  /** No spreads, just combining. */
  val policies : SpecificUserView_fullUser.Policies
  val id : String
  val rawId : String
}


object SpecificUserView_fullUser extends _root_.relay.graphql.GenericGraphQLTaggedNode {

  ////////////////////////////////////
  ////// Supporting classes begin here
  ////////////////////////////////////
  trait PoliciesEdgesNode extends js.Object {
    val quoteId : String
  }
  trait PoliciesEdges extends js.Object with _root_.relay.runtime.Edge[PoliciesEdgesNode] {
    /** No spreads, just combining. */
    val node : PoliciesEdgesNode
  }
  trait Policies extends js.Object with _root_.relay.runtime.Connection[PoliciesEdges] {
    /** No spreads, just combining. */
    val edges : js.Array[PoliciesEdges]
  }

  ///////////////////////////
  ////// Implicits begin here
  ///////////////////////////



  val query: _root_.relay.graphql.ConcreteFragment = _root_.scala.scalajs.js.eval("""({
  "kind": "Fragment",
  "name": "SpecificUserView_fullUser",
  "type": "FullUser",
  "metadata": null,
  "argumentDefinitions": [],
  "selections": [
    {
      "kind": "ScalarField",
      "alias": null,
      "name": "rawId",
      "args": null,
      "storageKey": null
    },
    {
      "kind": "ScalarField",
      "alias": null,
      "name": "id",
      "args": null,
      "storageKey": null
    },
    {
      "kind": "LinkedField",
      "alias": null,
      "name": "policies",
      "storageKey": null,
      "args": null,
      "concreteType": "PolicyMaterializedConnection",
      "plural": false,
      "selections": [
        {
          "kind": "LinkedField",
          "alias": null,
          "name": "edges",
          "storageKey": null,
          "args": null,
          "concreteType": "PolicyMaterializedEdge",
          "plural": true,
          "selections": [
            {
              "kind": "LinkedField",
              "alias": null,
              "name": "node",
              "storageKey": null,
              "args": null,
              "concreteType": "PolicyMaterialized",
              "plural": false,
              "selections": [
                {
                  "kind": "ScalarField",
                  "alias": null,
                  "name": "quoteId",
                  "args": null,
                  "storageKey": null
                }
              ]
            }
          ]
        }
      ]
    }
  ]
})""").asInstanceOf[_root_.relay.graphql.ConcreteFragment]
  val devText: String = """"""
}
